==> haskell-crypto-pubkey-types-0.4.3-75-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-6yHwzY078ghL3x4NeY3ZSX
key: crypto-pubkey-types-0.4.3-6yHwzY078ghL3x4NeY3ZSX
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: 6577a7d3dc7b4fae6150f17a206dfc9b
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-6yHwzY078ghL3x4NeY3ZSX
depends:
    asn1-encoding-0.9.5-IrdFZ5qrO7IC5velKcp00P
    asn1-types-0.3.2-AKDaaVglQIuo8QDrabVvn base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-78-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey-types
version: 0.4.3
id: crypto-pubkey-types-0.4.3-FhqgLxZCmWKFtnc6y8gHPQ
key: crypto-pubkey-types-0.4.3-FhqgLxZCmWKFtnc6y8gHPQ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis: Generic cryptography Public keys algorithm types
description:
    Generic cryptography public keys algorithm types
category: Cryptography
abi: b7a0ba9e80e36bfc70881267b04f8320
exposed: True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA
import-dirs: /usr/lib/ghc-8.6.2/site-local/crypto-pubkey-types-0.4.3
library-dirs: /usr/lib/ghc-8.6.2/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/crypto-pubkey-types-0.4.3
hs-libraries: HScrypto-pubkey-types-0.4.3-FhqgLxZCmWKFtnc6y8gHPQ
depends:
    asn1-encoding-0.9.5-8DGTSlCpMwuHaTltq7NmTe
    asn1-types-0.3.2-AnHjQ7P6LgBJI1DPVLNnWq base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
